PRO IMAGE_COMPOSITE, LIST, OUTFILE, MISSING=MISSING

;+
; NAME:
;   IMAGE_COMPOSITE
;
; PURPOSE:
;   Composite one or more input TIFF images into one output TIFF image.
;
;   If only one input image is available, the output image is identical
;   to the input image.
;
; USAGE:
;   IMAGE_COMPOSITE, LIST, OUTFILE
;-

;- Check arguments
if (n_elements(list) eq 0) then message, 'Argument LIST is undefined'
if (n_elements(outfile) eq 0) then message, 'Argument OUTFILE is undefined'
if (n_elements(missing) eq 0) then missing = [0B, 0B, 0B]

;- Read first input image
image_out = read_tiff(list[0])

;- If more than one input file was supplied, overlay the images in turn
if (n_elements(list) gt 1) then begin
  for index = 1, n_elements(list) - 1 do begin
    image_out = overlay_image(temporary(image_out), read_tiff(list[index]), missing=missing)
  endfor
endif

;- Write output file
write_tiff, outfile, image_out

END
