FUNCTION MODIS_FALSE_COLOR, RED, GRN, BLU, RANGE=RANGE, CLOUD=CLOUD

;- Apply piecewise linear enhancement to MODIS corrected reflectance data
;- to create false color images

;- Check keywords
if (n_elements(red) eq 0) then message, 'Argument RED is undefined'
if (n_elements(grn) eq 0) then message, 'Argument GRN is undefined'
if (n_elements(blu) eq 0) then message, 'Argument BLU is undefined'
if (n_elements(range) eq 0) then range = [-0.01, 1.10]

;- Rapid Response default enhancement: 0,0, 30,110, 60,160, 120,210, 190,240, 255,255
x = byte([0,  30,  60, 120, 190, 255])
y = byte([0, 110, 160, 210, 240, 255])

;- Rapid Response cloud enhancement: 0,0, 25,90, 55,140, 100,175, 255,255
if keyword_set(cloud) then begin
  x = byte([0, 25,  55, 100, 255])
  y = byte([0, 90, 140, 175, 255])
endif

;- Create output true color image array
dims = size(red, /dimensions)
nx = dims[0]
ny = dims[1]
true = bytarr(3, nx, ny, /nozero)

;- Scale each band
true[0, *, *] = scale_image(bytscl(red, min=range[0], max=range[1]), x, y)
true[1, *, *] = scale_image(bytscl(grn, min=range[0], max=range[1]), x, y)
true[2, *, *] = scale_image(bytscl(blu, min=range[0], max=range[1]), x, y)

;- Return result
return, true

END
