FUNCTION OVERLAY_IMAGE, IMAGE_ONE, IMAGE_TWO, MISSING=MISSING

;- Overlay image_two over image_one, where both images are
;- 24-bit true color with dimensions [3, NX, NY]
;- (default RGB value for missing pixels is [255B, 255B, 255B])

;- Check arguments
if (n_params() ne 2) then message, 'Usage: RESULT = OVERLAY_IMAGE(IMAGE_ONE, IMAGE_TWO)'
if (n_elements(image_one) eq 0) then message, 'Argument IMAGE_ONE is undefined'
if (n_elements(image_two) eq 0) then message, 'Argument IMAGE_TWO is undefined'
if (n_elements(missing) eq 0) then missing = [255B, 255B, 255B]

;- Get good (not missing) pixel mask for image_two
mask = $
  (reform(image_two[0, *, *]) ne missing[0]) and $
  (reform(image_two[1, *, *]) ne missing[1]) and $
  (reform(image_two[2, *, *]) ne missing[2])

;- Create empty output image
image_out = make_array(size=size(image_one))

;- Overlay the good pixels from image_two onto image_one
for dim = 0, 2 do image_out[dim, *, *] = $
  reform(image_two[dim, *, *]) * mask + $
  reform(image_one[dim, *, *]) * (1B - mask)

;- Return result
return, image_out

END
