#!/bin/bash

# Run MODIS corrected reflectance processing given MODIS L1B 1KM, HKM, QKM files.
#
# Usage: run_modis_crefl.bash fil_1km fil_hkm fil_qkm ref_1km ref_hkm ref_qkm

# Startup message
echo "Started "$0" at "`date`

# Check for DBGE_HOME environment variable
if [ -z "$DBGE_HOME" ]; then
  echo "Environment variable DBGE_HOME is not set"
  exit 1
fi

# Get arguments
fil_1km=$1
fil_hkm=$2
fil_qkm=$3
ref_1km=$4
ref_hkm=$5
ref_qkm=$6

# Create soft links to standard filenames expected by crefl
ln -fs $fil_1km MOD021KM.tmp.hdf
ln -fs $fil_hkm MOD02HKM.tmp.hdf
ln -fs $fil_qkm MOD02QKM.tmp.hdf

# Set up crefl environment
export ANCPATH=$DBGE_HOME/bin

# Run corrected reflectance code 1KM
echo
echo "Creating 1KM corrected reflectance in "$ref_1km
echo
$DBGE_HOME/bin/crefl -v -f -1km  MOD02HKM.tmp.hdf MOD02QKM.tmp.hdf MOD021KM.tmp.hdf -of=$ref_1km -bands=1,3,4

# Run corrected reflectance code HKM
echo
echo "Creating HKM corrected reflectance in "$ref_hkm
echo
$DBGE_HOME/bin/crefl -v -f -500m MOD02HKM.tmp.hdf MOD02QKM.tmp.hdf MOD021KM.tmp.hdf -of=$ref_hkm -bands=1,3,4

# Run corrected reflectance code QKM
echo
echo "Creating QKM corrected reflectance in "$ref_qkm
echo
$DBGE_HOME/bin/crefl -v -f -250m MOD02HKM.tmp.hdf MOD02QKM.tmp.hdf MOD021KM.tmp.hdf -of=$ref_qkm -bands=1,2

# Clean up
rm -f MOD02HKM.tmp.hdf MOD02QKM.tmp.hdf MOD021KM.tmp.hdf

# Exit
echo
echo "Finished "$0" at "`date`
exit 0
